@@ -132,9 +132,7 @@ def split_text_by_byte_length(text: Union[str, bytes], byte_length: int) -> List
     return words
 
 
-def mkssml(
-    text: Union[str, bytes], voice: str, pitch: str, rate: str, volume: str
-) -> str:
+def mkssml(text: Union[str, bytes], voice: str, rate: str, volume: str) -> str:
     """
     Creates a SSML string from the given parameters.
 
@@ -146,7 +144,7 @@ def mkssml(
 
     ssml = (
         "<speak version='1.0' xmlns='http://www.w3.org/2001/10/synthesis' xml:lang='en-US'>"
-        f"<voice name='{voice}'><prosody pitch='{pitch}' rate='{rate}' volume='{volume}'>"
+        f"<voice name='{voice}'><prosody pitch='+0Hz' rate='{rate}' volume='{volume}'>"
         f"{text}</prosody></voice></speak>"
     )
     return ssml
@@ -197,7 +195,6 @@ class Communicate:
         text: str,
         voice: str = "Microsoft Server Speech Text to Speech Voice (en-US, AriaNeural)",
         *,
-        pitch: str = "+0Hz",
         rate: str = "+0%",
         volume: str = "+0%",
         proxy: Optional[str] = None,
@@ -231,15 +228,11 @@ class Communicate:
         ):
             raise ValueError(f"Invalid voice '{voice}'.")
 
-        if re.match(r"^[+-]\d+Hz$", pitch) is None:
-            raise ValueError(f"Invalid pitch '{pitch}'.")
-        self.pitch: str = pitch
-
-        if re.match(r"^[+-]0*([0-9]|([1-9][0-9])|100)%$", rate) is None:
+        if re.match(r"^[+-]?\d+%$", rate) is None:
             raise ValueError(f"Invalid rate '{rate}'.")
         self.rate: str = rate
 
-        if re.match(r"^[+-]0*([0-9]|([1-9][0-9])|100)%$", volume) is None:
+        if re.match(r"^[+-]?\d+%$", volume) is None:
             raise ValueError(f"Invalid volume '{volume}'.")
         self.volume: str = volume
 
@@ -254,7 +247,7 @@ class Communicate:
                 ssml_headers_plus_data(
                     connect_id(),
                     date_to_string(),
-                    mkssml("", self.voice, self.pitch, self.rate, self.volume),
+                    mkssml("", self.voice, self.rate, self.volume),
                 )
             )
             + 50  # margin of error
@@ -320,9 +313,7 @@ class Communicate:
                         ssml_headers_plus_data(
                             connect_id(),
                             date,
-                            mkssml(
-                                text, self.voice, self.pitch, self.rate, self.volume
-                            ),
+                            mkssml(text, self.voice, self.rate, self.volume),
                         )
                     )
 
